//	SonicPlayer
//	www.paulsprojects.net
//
//	Copyright (c) 2008, Paul Baker
//	All rights reserved.
//
//	Redistribution and use in source and binary forms, with or without modification,
//	are permitted provided that the following conditions are met:
//
//	    * Redistributions of source code must retain the above copyright notice,
//	      this list of conditions and the following disclaimer.
//	    * Redistributions in binary form must reproduce the above copyright notice,
//	      this list of conditions and the following disclaimer in the documentation
//	      and/or other materials provided with the distribution.
//	    * Neither the name of paulsprojects.net nor the names of its contributors
//	      may be used to endorse or promote products derived from this software
//	      without specific prior written permission.
//
//	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
//	ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
//	WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
//	DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
//	ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
//	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
//	LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
//	ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
//	SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

#include <cassert>
#include <vector>
#include "YM2151.h"
#include "MAME/ym2151.h"

namespace VGM_Player
{
	YM2151::YM2151(unsigned int clock_)
	{
		ym2151 = YM2151Init(0, clock_, 44100);
	}
		
	void YM2151::WriteRegister(unsigned char address, unsigned char data)
	{
		YM2151WriteReg(ym2151, address, data);
	}

	array<short>^ YM2151::CalculateSamples(int numSamples)
	{
		assert(numSamples > 0);

		std::vector<short> leftSamples(numSamples);
		std::vector<short> rightSamples(numSamples);
		short * buffers[] = {&leftSamples[0], &rightSamples[0]};
		YM2151UpdateOne(ym2151, buffers, numSamples);

		array<short>^ samples = gcnew array<short>(numSamples * 2);
		for(int i = 0; i < numSamples; ++i)
		{
			samples[i * 2] = leftSamples[i];
			samples[i * 2 + 1] = rightSamples[i];
		}

		return samples;
	}

	void YM2151::Reset()
	{
		YM2151ResetChip(ym2151);
	}
}